@@ -7,13 +7,13 @@ import elasticsearch
 import elasticsearch_dsl
 import fatcat_openapi_client
 import requests
-from dynaconf import Dynaconf
 from fatcat_openapi_client import ContainerEntity, DefaultApi, ReleaseEntity
 from fatcat_openapi_client.rest import ApiException
 
 from fuzzycat.entities import entity_from_dict, entity_from_json
+from fuzzycat.utils import es_compat_hits_total
+from fuzzycat.config import settings
 
-settings = Dynaconf(envvar_prefix="FUZZYCAT")
 FATCAT_API_URL = settings.get("FATCAT_API_URL", "https://api.fatcat.wiki/v0")
 
 
@@ -63,7 +63,13 @@ def match_release_fuzzy(
         value = getattr(ext_ids, attr)
         if not value:
             continue
-        r = api.lookup_release(**{attr: value})
+        try:
+            r = api.lookup_release(**{attr: value})
+        except fatcat_openapi_client.rest.ApiException as err:
+            if err.status in [404, 400]:
+                r = None
+            else:
+                raise err
         if r:
             return [r]
 
@@ -79,7 +85,7 @@ def match_release_fuzzy(
         "size": size,
     }
     resp = es.search(body=body, index="fatcat_release")
-    if resp["hits"]["total"] > 0:
+    if es_compat_hits_total(resp) > 0:
         return response_to_entity_list(resp, entity_type=ReleaseEntity, api=api)
 
     # Get fuzzy.
@@ -97,7 +103,7 @@ def match_release_fuzzy(
         "size": size,
     }
     resp = es.search(body=body, index="fatcat_release")
-    if resp["hits"]["total"] > 0:
+    if es_compat_hits_total(resp) > 0:
         return response_to_entity_list(resp, entity_type=ReleaseEntity, api=api)
 
     # TODO: perform more queries on other fields.
@@ -209,9 +215,9 @@ def anything_to_entity(
 
     if re.match("[0-9]{4}(-)?[0-9]{3,3}[0-9xx]", s):
         # TODO: make index name configurable
-        url = "{}/fatcat_{}/_search?q=issns:{}".format(es_url, entity_name, s)
+        url = "{}/fatcat_{}/_search?track_total_hits=true&q=issns:{}".format(es_url, entity_name, s)
         doc = requests.get(url).json()
-        if doc["hits"]["total"] == 1:
+        if es_compat_hits_total(resp) == 1:
             ident = doc["hits"]["hits"][0]["_source"]["ident"]
             url = "{}/{}/{}".format(api_url, entity_name, ident)
             return entity_from_json(requests.get(url).text, entity_type)
